==> react-native-ui-view-0.0.6.tgz: package/esm/components/TabBar/index.js <==
import React, { Children, cloneElement } from 'react';
import { StyleSheet, View, SafeAreaView } from 'react-native';
const TabBar = props => {
    const { height = 50, iconSize = 20, activeColor = '#5098FF', inactiveColor = '#606266', showBorderTop = true, backgroundColor = '#FFFFFF', children, } = props;
    const getPanes = (showContent) => {
        let selectedIndex = 0;
        [].concat(children).forEach((child, idx) => {
            if (child.props.selected) {
                selectedIndex = idx;
            }
        });
        const newChildren = [];
        Children.map(children, (child, idx) => {
            if (showContent && selectedIndex === idx) {
                newChildren.push(React.createElement(View, { key: idx, style: { flex: 1 } }, child.props.children));
            }
            else {
                newChildren.push(cloneElement(child, {
                    key: idx,
                    activeColor,
                    inactiveColor,
                    iconSize,
                }));
            }
        });
        if (showContent) {
            return newChildren.filter((_, i) => i === selectedIndex);
        }
        return newChildren;
    };
    return (React.createElement(SafeAreaView, { style: [styles.page, { paddingBottom: height }] },
        getPanes(true),
        React.createElement(View, { style: [styles.tabBar, { backgroundColor, height }, showBorderTop && styles.borderTop] }, getPanes(false))));
};
const styles = StyleSheet.create({
    page: {
        position: 'relative',
        flex: 1,
    },
    tabBar: {
        position: 'absolute',
        bottom: 0,
        left: 0,
        width: '100%',
        display: 'flex',
        flexDirection: 'row',
    },
    borderTop: {
        borderTopColor: '#E4E7ED',
        borderTopWidth: 1,
    },
});
export default TabBar;

==> react-native-ui-view-0.0.7.tgz: package/esm/components/TabBar/index.js <==
import React, { Children, cloneElement } from 'react';
import { StyleSheet, View, SafeAreaView } from 'react-native';
const TabBar = props => {
    const { height = 50, iconSize = 20, activeColor = '#5098FF', inactiveColor = '#606266', showBorderTop = true, backgroundColor = '#FFFFFF', children, } = props;
    const getPanes = (showContent) => {
        let selectedIndex = 0;
        [].concat(children).forEach((child, idx) => {
            if (child.props.selected) {
                selectedIndex = idx;
            }
        });
        const newChildren = [];
        Children.map(children, (child, idx) => {
            if (showContent && selectedIndex === idx) {
                newChildren.push(React.createElement(View, { key: idx, style: { flex: 1, paddingBottom: height } }, child.props.children));
            }
            else {
                newChildren.push(cloneElement(child, {
                    key: idx,
                    activeColor,
                    inactiveColor,
                    iconSize,
                }));
            }
        });
        if (showContent) {
            return newChildren.filter((_, i) => i === selectedIndex);
        }
        return newChildren;
    };
    return (React.createElement(SafeAreaView, { style: [styles.page] },
        getPanes(true),
        React.createElement(View, { style: [styles.tabBar, { backgroundColor, height }, showBorderTop && styles.borderTop] }, getPanes(false))));
};
const styles = StyleSheet.create({
    page: {
        flex: 1,
    },
    tabBar: {
        position: 'absolute',
        bottom: 0,
        left: 0,
        width: '100%',
        display: 'flex',
        flexDirection: 'row',
    },
    borderTop: {
        borderTopColor: '#E4E7ED',
        borderTopWidth: 1,
    },
});
export default TabBar;
